@@ -32,22 +32,18 @@ DESCRIPTION="The Extra Cmake Modules package contains extra CMake modules used b
 
 VERSION_EXT=$(basename $PKG_EXTRA_CMAKE_MODULES .tar.xz | cut -d "-" -f 2) 
 
-sed -i '/"lib64"/s/64//' kde-modules/KDEInstallDirsCommon.cmake &&
+source /etc/profile
+
+sed -i '/"lib64"/s/64//' kde-modules/KDEInstallDirsCommon.cmake
 
 sed -e '/PACKAGE_INIT/i set(SAVE_PACKAGE_PREFIX_DIR "${PACKAGE_PREFIX_DIR}")' \
     -e '/^include/a set(PACKAGE_PREFIX_DIR "${SAVE_PACKAGE_PREFIX_DIR}")' \
-    -i ECMConfig.cmake.in &&
+    -i ECMConfig.cmake.in
+	
+mkdir build
+cd    build
 
-#sed ... Modules/KDEInstallDirs.cmake: This command disables applications using cmake from attempting to install files in a lib64 sub-directory.
-
-#sed ... ECMConfig.cmake.in: This command protects the global cmake variable PACKAGE_PREFIX_DIR from being changed when checking ECM presence: 
-#			since we install ECM into /usr, the check would set that variable to /usr, while most KDE packages expect it to be set to /opt/kf6 
-#			and would fail to build if it is set to something else.
-
-mkdir build &&
-cd    build &&
-
-cmake -D CMAKE_INSTALL_PREFIX=/usr -D BUILD_WITH_QT6=ON .. &&
+cmake -D CMAKE_INSTALL_PREFIX=/usr -D BUILD_WITH_QT6=ON ..
 make
 
 
